import express from 'express'
import bodyParser from 'body-parser'
import mongoose from 'mongoose'
import bcrypt from 'bcrypt'
import jwt from 'jwt-simple'
import bhttp from 'bhttp'
import fs from 'fs'

import config from './config/database'
import User from './models/user'
import swisstennis from './routes/swisstennis'

const port = process.env.PORT || 3002
const app = express()

app.use(bodyParser.urlencoded({ extended: false }))
app.use(bodyParser.json())

app.get('/', (req, res) => {
  res.send(`Express API at http://localhost:${port}/api`)
})

mongoose.connect(config.database, {
  connectTimeoutMS: 1000
})
const apiRoutes = express.Router()

apiRoutes.post('/login', (req, res) => {
  const { username, password } = req.body
  if (!username || !password) {
    res.status(400).json({ success: false, msg: 'Parameters name and password are required' })
    return
  }

  User.findOne({ name: username }, (err, user) => {
    if (err) {
      res.status(400).json({ success: false, msg: err })
      return
    }
    if (!user) {
      res.status(400).json({ success: false, msg: 'Authentication failed. User not found.' })
      return
    }
    console.log(password, user)
    if (!bcrypt.compareSync(password, user.password)) {
      res.status(400).json({ success: false, msg: 'Authentication failed. Wrong password' })
    } else {
      const token = jwt.sign({
        exp: Math.floor(Date.now() / 1000) + 24*60*60,
        data: user
      }, "bugu")
      res.json({ success: true, token })
    }
  })
})

apiRoutes.use('/swisstennis', swisstennis)

app.use('/api', apiRoutes)

app.listen(port)
console.log(`Server running on port ${port}.`)
